==> wcomponents-theme-1.0.5.jar: theme/wcomponents-theme/scripts_debug/wc/i18n/en.js <==
define({
	"asciimap":"{\"\\u00e0\\u00e2\\u00e4\": \"a\",\"\\u00e8\\u00e9\\u00ea\\u00eb\": \"e\",\"\\u00ee\\u00ef\": \"i\",\"\\u00f4\": \"o\",\"\\u00f9\\u00fb\\u00fc\": \"u\",\"c\": \"\\u00e7\"}",
	"btt0":"Back to top (press the ESCAPE key to hide this)",
	"cbg1":"Select one or more options",
	"cbg2":"SHIFT + click to action a range of options",
	"chi1":"selected",
	"chi2":"not selected",
	"cm0":"Expand all",
	"cm1":"This component requires a label",
	"cm2":"required",
	"cm3":"Changing the value or selection of this component will cause all of your changes to be saved immediately.",
	"cm4":"[a-zA-Z]",
	"cu1":"has unsaved changes. Would you like to discard them?",
	"cu2":"This page",
	"day0":"Sunday",
	"day1":"Monday",
	"day2":"Tuesday",
	"day3":"Wednesday",
	"day4":"Thursday",
	"day5":"Friday",
	"day6":"Saturday",
	"df0":"Shortcuts: t/y/m = today/yesterday/tomorrow. \\n+/-N = +/-N days from now, e.g. +7.",
	"df1":"d M yy,M d yy,d M yyyy,M d yyyy,d MON yy,d MON yyyy,dd MON yy,dd MON yyyy,dMyy,dMyyyy,dMMyy,dMMyyyy,ddMMyyyy,ddMMyy,ddMMyyyy,ddMyyyy,ddMyy,dMONyy,dMONyyyy,yyyy-MM-dd,yyyyMMdd,dd/MM/yyyy,dd/M/yyyy,d/MM/yyyy,d/M/yyyy,dd/MM/yy,dd/M/yy,d/MM/yy,d/M/yy,MM/dd/yyyy,M/yyyydd/,MM/d/yyyy,M/d/yyyy,MM/dd/yy,M/dd/yy,MM/d/yy,M/d/yy,MMddyy,MMddyyyy,MMdyyyy,MMdyy,Mddyyyy,Mddyy,Mdyy,Mdyyyy",
	"df10":"Previous month",
	"df11":"Next month",
	"df12":"Today",
	"df13":"Close",
	"df2":"M y,MON y,M yyyy,MON yyyy,MONy,MONyy,MONyyyy,MMyy,MMyyyy,yyyyMM,yyyyM,Myy,Myyyy,yyMM,yyM,y,yyyy,M,MM,MON,d M,M d,dM,Md,dMM,MMd,ddMM,MMdd,ddM,Mdd,d MON,MON d,dd MON,MON dd,dMON,MONd,ddMON,MONdd,d,dd yyyy,ddyyyy,ddyy,dd yy,dyyyy,dyy",
	"df3":"dd MON yyyy",
	"df6":"yyyy",
	"df7":"Month",
	"df8":"Year",
	"df9":"Calendar date picker",
	"dlg0":"Untitled Dialog",
	"dlg1":"ARROW to move dialog",
	"dlg2":"ARROW RIGHT or ARROW_DOWN to enlarge dialog, ARROW LEFT or  ARROW UP to shrink dialog",
	"dlg3":"Close dialog",
	"dlg4":"Maximise/restore dialog",
	"iet0":"Rotate",
	"iet1":"Left",
	"iet10":"Image Editor",
	"iet11":"Left 90º",
	"iet12":"Right 90º",
	"iet2":"Right",
	"iet3":"Move",
	"iet4":"Left",
	"iet5":"Right",
	"iet6":"Up",
	"iet7":"Down",
	"iet8":"Zoom",
	"iet9":"In",
	"ietA":"Out",
	"ietB":"Reset",
	"ietC":"Cancel",
	"ietD":"Save",
	"ietE":"Photo",
	"ietF":"Speed",
	"ietF1":"Your browser does not support webcam capture",
	"lang":"en",
	"load1":"Loading",
	"locale":"en",
	"lsc1":"move to top",
	"lsc2":"move up",
	"lsc3":"move down",
	"lsc4":"move to bottom",
	"lstldr0":"An error occurred loading the list%s",
	"lstldr1":"Retry",
	"mb0":"An error has occurred",
	"mb1":"Warning",
	"mb2":"Information",
	"mb3":"Success",
	"media1":"play",
	"media2":"pause",
	"menu1":"wc_coleast",
	"menu2":"wc_colwest",
	"menu3":"Close",
	"mfc0":"Add item to: ",
	"mfc1":"Remove item. Shift + click remove button to remove all.",
	"mfc2":"select an option",
	"mfc3":"You have reached the maximum options to select.",
	"mfu0":"The file you have selected is too large (%1$s %3$s).\\nMaximum file size is %2$s %3$s.",
	"mfu1":"The file you have selected is not of an accepted type.\\nOnly the following type/s are accepted: %s.",
	"mfu2":"If you navigate away from this page your current file upload will be cancelled.\\nAre you sure you wish to proceed?",
	"mfu3":"bytes",
	"mfu4":"file selector",
	"mfu5":"kilobytes",
	"mfu6":"megabytes",
	"mfu7":"gigabytes",
	"mfu8":"Are you sure you wish to remove this file?",
	"mfu9":"You cannot upload more files, the maximum allowed is %2$s.",
	"mnth0":"January",
	"mnth1":"February",
	"mnth2":"March",
	"mnth3":"April",
	"mnth4":"May",
	"mnth5":"June",
	"mnth6":"July",
	"mnth7":"August",
	"mnth8":"September",
	"mnth9":"October",
	"mnthA":"November",
	"mnthB":"December",
	"mnthabbr0":"Jan",
	"mnthabbr1":"Feb",
	"mnthabbr2":"Mar",
	"mnthabbr3":"Apr",
	"mnthabbr4":"May",
	"mnthabbr5":"Jun",
	"mnthabbr6":"Jul",
	"mnthabbr7":"Aug",
	"mnthabbr8":"Sep",
	"mnthabbr9":"Oct",
	"mnthabbrA":"Nov",
	"mnthabbrB":"Dec",
	"msp0":"Add ",
	"msp1":"Add All ",
	"msp2":"Remove",
	"msp3":"Remove All",
	"mx0":"%d characters remaining",
	"p1":"Untitled Section",
	"rbg1":"Select an option",
	"rt0":"You must have JavaScript enabled to use this application.",
	"sbxs1":"abcdefghijklmnopqrstuvwxyz0123456789~`!@#$%^&*()-_=+[{]}\\|;:'\",<.>/? ",
	"sk1":"Skip to ",
	"tble1":"No data",
	"tble13":"Select/deselect all",
	"tble4":"Expand or collapse sections",
	"tble5":"Sorted descending",
	"tble6":"Sorted ascending",
	"tble7":"Sortable but not sorted",
	"tog1":"Select:",
	"tog2":"All",
	"tog3":"None",
	"tog4":"Select all",
	"tog5":"Collapse all",
	"tre1":"Show/hide content",
	"trs1":"Select one or more rows",
	"trs2":"Select a row",
	"twm1":"Warning",
	"twm2":"<p>Your session will be automatically ended within the next %s minutes.</p><p>This is because the server has not registered any activity for some time.</p><p>To reset your session timer you can do one of the following actions:</p><ul><li>save your work; or</li><li>navigate to a different page.</li></ul>",
	"twm3":"Session Expired",
	"twm4":"<p>Your session has expired.</p><p>There may have been changes that were not saved.</p><p>To start a new session you can do one of the following actions:</p><ul><li>navigate to the home page; or</li><li>close this window and open a new application.</li></ul>",
	"wdtp0":"First page",
	"wdtp1":"Previous page",
	"wdtp10":"all",
	"wdtp2":"Next page",
	"wdtp3":"Last page",
	"wdtp4":"Page",
	"wdtp5":"1 result",
	"wdtp6":"^ of # results",
	"wdtp7":"^ - | of # results",
	"wdtp9":"Rows per page"
});

==> wcomponents-theme-1.1.4.jar: theme/wcomponents-theme/scripts_debug/wc/i18n/en.js <==
define({
	"asciimap":"{\"\\u00e0\\u00e2\\u00e4\": \"a\",\"\\u00e8\\u00e9\\u00ea\\u00eb\": \"e\",\"\\u00ee\\u00ef\": \"i\",\"\\u00f4\": \"o\",\"\\u00f9\\u00fb\\u00fc\": \"u\",\"c\": \"\\u00e7\"}",
	"btt0":"Back to top (press the ESCAPE key to hide this)",
	"cbg1":"Select one or more options",
	"cbg2":"SHIFT + click to action a range of options",
	"chi1":"selected",
	"chi2":"not selected",
	"cm0":"Expand all",
	"cm1":"This component requires a label",
	"cm2":"required",
	"cm3":"Changing the value or selection of this component will cause all of your changes to be saved immediately.",
	"cm4":"[a-zA-Z]",
	"cu1":"has unsaved changes. Would you like to discard them?",
	"cu2":"This page",
	"day0":"Sunday",
	"day1":"Monday",
	"day2":"Tuesday",
	"day3":"Wednesday",
	"day4":"Thursday",
	"day5":"Friday",
	"day6":"Saturday",
	"df0":"Shortcuts: t/y/m = today/yesterday/tomorrow. +/-N = +/-N days from now, e.g. +7.",
	"df1":"d M yy,M d yy,d M yyyy,M d yyyy,d MON yy,d MON yyyy,dd MON yy,dd MON yyyy,dMyy,dMyyyy,dMMyy,dMMyyyy,ddMMyyyy,ddMMyy,ddMMyyyy,ddMyyyy,ddMyy,dMONyy,dMONyyyy,yyyy-MM-dd,yyyyMMdd,dd/MM/yyyy,dd/M/yyyy,d/MM/yyyy,d/M/yyyy,dd/MM/yy,dd/M/yy,d/MM/yy,d/M/yy,MM/dd/yyyy,M/yyyydd/,MM/d/yyyy,M/d/yyyy,MM/dd/yy,M/dd/yy,MM/d/yy,M/d/yy,MMddyy,MMddyyyy,MMdyyyy,MMdyy,Mddyyyy,Mddyy,Mdyy,Mdyyyy",
	"df10":"Previous month",
	"df11":"Next month",
	"df12":"Today",
	"df13":"Close",
	"df2":"M y,MON y,M yyyy,MON yyyy,MONy,MONyy,MONyyyy,MMyy,MMyyyy,yyyyMM,yyyyM,Myy,Myyyy,yyMM,yyM,y,yyyy,M,MM,MON,d M,M d,dM,Md,dMM,MMd,ddMM,MMdd,ddM,Mdd,d MON,MON d,dd MON,MON dd,dMON,MONd,ddMON,MONdd,d,dd yyyy,ddyyyy,ddyy,dd yy,dyyyy,dyy",
	"df3":"dd MON yyyy",
	"df6":"yyyy",
	"df7":"Month",
	"df8":"Year",
	"df9":"Calendar date picker",
	"dlg0":"Untitled Dialog",
	"dlg1":"ARROW to move dialog",
	"dlg2":"ARROW RIGHT or ARROW_DOWN to enlarge dialog, ARROW LEFT or  ARROW UP to shrink dialog",
	"dlg3":"Close dialog",
	"dlg4":"Maximise/restore dialog",
	"iet0":"Rotate",
	"iet1":"Left",
	"iet10":"Image Editor",
	"iet11":"Left 90º",
	"iet12":"Right 90º",
	"iet2":"Right",
	"iet3":"Move",
	"iet4":"Left",
	"iet5":"Right",
	"iet6":"Up",
	"iet7":"Down",
	"iet8":"Zoom",
	"iet9":"In",
	"ietA":"Out",
	"ietB":"Reset",
	"ietC":"Cancel",
	"ietD":"Save",
	"ietE":"Photo",
	"ietF":"Speed",
	"ietF1":"Your browser does not support webcam capture",
	"lang":"en",
	"load1":"Loading",
	"locale":"en",
	"lsc1":"move to top",
	"lsc2":"move up",
	"lsc3":"move down",
	"lsc4":"move to bottom",
	"lstldr0":"An error occurred loading the list%s",
	"lstldr1":"Retry",
	"mb0":"An error has occurred",
	"mb1":"Warning",
	"mb2":"Information",
	"mb3":"Success",
	"media1":"play",
	"media2":"pause",
	"menu0":"wc_coleast",
	"menu1":"wc_colwest",
	"menu2":"Close",
	"menu3":"Open",
	"mfc0":"Add item to: ",
	"mfc1":"Remove item. Shift + click remove button to remove all.",
	"mfc2":"select an option",
	"mfc3":"You have reached the maximum options to select.",
	"mfu0":"The file you have selected is too large (%1$s %3$s). Maximum file size is %2$s %3$s.",
	"mfu1":"The file you have selected is not of an accepted type. Only the following type/s are accepted: %s.",
	"mfu2":"If you navigate away from this page your current file upload will be cancelled. Are you sure you wish to proceed?",
	"mfu3":"bytes",
	"mfu4":"file selector",
	"mfu5":"kilobytes",
	"mfu6":"megabytes",
	"mfu7":"gigabytes",
	"mfu8":"Are you sure you wish to remove this file?",
	"mfu9":"You cannot upload more files, the maximum allowed is %2$s.",
	"mnth0":"January",
	"mnth1":"February",
	"mnth2":"March",
	"mnth3":"April",
	"mnth4":"May",
	"mnth5":"June",
	"mnth6":"July",
	"mnth7":"August",
	"mnth8":"September",
	"mnth9":"October",
	"mnthA":"November",
	"mnthB":"December",
	"mnthabbr0":"Jan",
	"mnthabbr1":"Feb",
	"mnthabbr2":"Mar",
	"mnthabbr3":"Apr",
	"mnthabbr4":"May",
	"mnthabbr5":"Jun",
	"mnthabbr6":"Jul",
	"mnthabbr7":"Aug",
	"mnthabbr8":"Sep",
	"mnthabbr9":"Oct",
	"mnthabbrA":"Nov",
	"mnthabbrB":"Dec",
	"msp0":"Add ",
	"msp1":"Add All ",
	"msp2":"Remove",
	"msp3":"Remove All",
	"mx0":"%d characters remaining",
	"p1":"Untitled Section",
	"rbg1":"Select an option",
	"rt0":"You must have JavaScript enabled to use this application.",
	"sbxs1":"abcdefghijklmnopqrstuvwxyz0123456789~`!@#$%^&*()-_=+[{]}\\|;:'\",<.>/? ",
	"sk1":"Skip to ",
	"tble1":"No data",
	"tble13":"Select/deselect all",
	"tble4":"Expand or collapse sections",
	"tble5":"Sorted descending",
	"tble6":"Sorted ascending",
	"tble7":"Sortable but not sorted",
	"tog1":"Select:",
	"tog2":"All",
	"tog3":"None",
	"tog4":"Select all",
	"tog5":"Collapse all",
	"tr0":"Expand/collapse this branch",
	"tre1":"Show/hide content",
	"trs1":"Select one or more rows",
	"trs2":"Select a row",
	"twm1":"Warning",
	"twm2":"<p>Your session will be automatically ended within the next %s minutes.</p><p>This is because the server has not registered any activity for some time.</p><p>To reset your session timer you can do one of the following actions:</p><ul><li>save your work; or</li><li>navigate to a different page.</li></ul>",
	"twm3":"Session Expired",
	"twm4":"<p>Your session has expired.</p><p>There may have been changes that were not saved.</p><p>To start a new session you can do one of the following actions:</p><ul><li>navigate to the home page; or</li><li>close this window and open a new application.</li></ul>",
	"val_c0":"%s must be completed.",
	"val_c1":"This field",
	"val_c2":"%s is not in the required format.",
	"val_c3":"%s must have at least one field completed.",
	"val_c4":"%1$s must have no more than %2$s options selected.",
	"val_c5":"%1$s must have at least %2$s options selected.",
	"val_c6":"%1$s and %2$s",
	"val_c7":"Successfully updated.",
	"val_df0":"%1$s must include at least one of a date (1-31) and/or month (1-12 or %2$s) and/or year (for example %3$d).",
	"val_df1":"%s must be a full date with day, month and year.",
	"val_df2":"%1$s must be on or after %2$s.",
	"val_df3":"%1$s must be on or before %2$s.",
	"val_df4":"%1$s - %2$s",
	"val_mfc0":"%1$s must have at least %2$s values entered.",
	"val_mfc1":"%1$s must have no more than %2$s values entered.",
	"val_mfu0":"%s must have at least one file uploaded.",
	"val_msp0":"%1$s must have at least one option added to the %2$s list.",
	"val_msp1":"%1$s must have no more than %2$s options in the %3$s list.",
	"val_msp2":"%1$s must have at least %2$s options in the %3$s list.",
	"val_mx0":"%1$s is limited to %2$s characters and currently %3$d are entered.",
	"val_nf0":"%1$s must be at least %2$s.",
	"val_nf1":"%1$s must be no more than %2$s.",
	"val_nf2":"%1$s must be between %2$s and %3$s.",
	"val_nf3":"%s must be a number.",
	"val_nf4":"%1$s must be a number of at least %2$s.",
	"val_nf5":"%1$s must be a number no more than %2$s.",
	"val_nf6":"%1$s must be a number between %2$s and %3$s.",
	"val_tf0":"%s must be in the format %s.",
	"val_tf1":"%s must be an email address.",
	"val_tf2":"%1$s must contain a minimum of %2$s characters.",
	"wdtp0":"First page",
	"wdtp1":"Previous page",
	"wdtp10":"all",
	"wdtp2":"Next page",
	"wdtp3":"Last page",
	"wdtp4":"Page",
	"wdtp5":"1 result",
	"wdtp6":"^ of # results",
	"wdtp7":"^ - | of # results",
	"wdtp9":"Rows per page"
});
